@@ -50,10 +50,10 @@ from beer_garden.api.http.processors import EventManager, websocket_publish
 from beer_garden.events import publish
 from beer_garden.events.processors import QueueListener
 
-io_loop: IOLoop
+io_loop: IOLoop = None
 server: HTTPServer
 tornado_app: Application
-logger: logging.Logger
+logger: logging.Logger = None
 event_publishers = None
 api_spec: APISpec
 anonymous_principal: Principal
@@ -207,7 +207,7 @@ def _setup_tornado_app() -> Application:
         (rf"{prefix}api/v1/tokens/(\w+)/?", v1.token.TokenAPI),
         (rf"{prefix}api/v1/jobs/(\w+)/?", v1.job.JobAPI),
         (rf"{prefix}api/v1/logging/?", v1.logging.LoggingAPI),
-        (rf"{prefix}api/v1/gardens/(\w+)/?", v1.garden.GardenAPI),
+        (rf"{prefix}api/v1/gardens/([\w%]+)/?", v1.garden.GardenAPI),
         (rf"{prefix}api/v1/files/?", v1.file.FileAPI),
         (rf"{prefix}api/v1/files/id/?", v1.file.FileNameAPI),
         # Beta
