@@ -17,7 +17,7 @@ import pika.spec
 import six
 import urllib3
 
-
+from beer_garden.errors import NotUniqueException
 from brewtils.choices import parse
 from brewtils.errors import ConflictError, ModelValidationError, RequestPublishException
 from brewtils.models import Choices, Events, Request, RequestTemplate, System, Operation
@@ -158,6 +158,7 @@ class RequestValidator(object):
                         "Output Type for Request was %s but the command specified "
                         "the type as %s" % (request.output_type, command.output_type)
                     )
+                request.hidden = command.hidden
 
                 return command
 
@@ -308,7 +309,13 @@ class RequestValidator(object):
                         " must be a string or dictionary " % command_parameter.key
                     )
 
-                response = process_wait(choices_request, self._command_timeout)
+                try:
+                    response = process_wait(choices_request, self._command_timeout)
+                except TimeoutError:
+                    raise ModelValidationError(
+                        "Unable to validate choices for parameter '%s' - Choices "
+                        "request took too long to complete" % command_parameter.key
+                    )
 
                 raw_allowed = json.loads(response.output)
 
@@ -767,7 +774,9 @@ def process_wait(request: Request, timeout: float) -> Request:
             kwargs={"wait_event": req_complete},
         )
     )
-    req_complete.wait(timeout)
+
+    if not req_complete.wait(timeout):
+        raise TimeoutError("Request did not complete before the specified timeout")
 
     return db.query_unique(Request, id=created_request.id)
 
@@ -793,8 +802,11 @@ def handle_event(event):
     elif event.garden != config.get("garden.name"):
 
         if event.name == Events.REQUEST_CREATED.name:
-            if db.query_unique(Request, id=event.payload.id) is None:
+            # Attempt to create the request, if it already exists then continue on
+            try:
                 db.create(event.payload)
+            except NotUniqueException:
+                pass
 
         elif event.name in (Events.REQUEST_STARTED.name, Events.REQUEST_COMPLETED.name):
             # When we send child requests to child gardens where the parent was on
