@@ -21,20 +21,16 @@ from concurrent.futures.thread import ThreadPoolExecutor
 from functools import partial
 from typing import Dict, Union
 
-import requests
 import stomp
+from brewtils import EasyClient
+from brewtils.models import Event, Events, Garden, Operation, Request, System
 from stomp.exception import ConnectFailedException
-from beer_garden.api.stomp.processors import (
-    append_headers as stomp_append_headers,
-    process_send_message as stomp_process_message,
-)
-from brewtils.models import Events, Garden, Operation, Request, System, Event
-from brewtils.schema_parser import SchemaParser
 
 import beer_garden
 import beer_garden.commands
 import beer_garden.config as config
 import beer_garden.db.api as db
+import beer_garden.files
 import beer_garden.garden
 import beer_garden.local_plugins.manager
 import beer_garden.log
@@ -44,9 +40,10 @@ import beer_garden.queues
 import beer_garden.requests
 import beer_garden.scheduler
 import beer_garden.systems
-import beer_garden.files
+from beer_garden.api.stomp.transport import consolidate_headers, process
 from beer_garden.errors import RoutingRequestException, UnknownGardenException
 from beer_garden.events import publish
+from beer_garden.events.processors import BaseProcessor
 from beer_garden.garden import get_garden, get_gardens
 from beer_garden.requests import complete_request
 
@@ -69,6 +66,9 @@ garden_lock = threading.Lock()
 gardens: Dict[str, Garden] = {}  # garden_name -> garden
 stomp_garden_connections: Dict[str, stomp.Connection] = {}
 
+# Used by entry points
+forward_processor: BaseProcessor
+
 # Used for determining WHERE to route an operation
 routing_lock = threading.Lock()
 system_name_routes: Dict[str, str] = {}
@@ -276,8 +276,8 @@ def initiate_forward(operation: Operation):
 
         raise
 
-    # If None is returned and this is a Request Create, return locally created Request
-    if not response and operation.operation_type == "REQUEST_CREATE":
+    # If this is a request create return locally created Request
+    if operation.operation_type == "REQUEST_CREATE":
         return operation.model
 
     return response
@@ -336,7 +336,10 @@ def forward(operation: Operation):
 
 def setup_stomp(garden):
     host_and_ports = [
-        (garden.connection_params["stomp_host"], garden.connection_params["stomp_port"])
+        (
+            garden.connection_params.get("stomp_host"),
+            garden.connection_params.get("stomp_port"),
+        )
     ]
     conn = stomp.Connection(host_and_ports=host_and_ports)
     if garden.connection_params.get("stomp_ssl"):
@@ -579,10 +582,9 @@ def _forward_stomp(operation: Operation, target_garden: Garden):
                     "client-id": target_garden.connection_params["stomp_username"]
                 },
             )
-        message, response_headers = stomp_process_message(operation)
-        response_headers = stomp_append_headers(
-            response_headers=response_headers,
-            garden_headers=target_garden.connection_params.get("stomp_headers"),
+        message, response_headers = process(operation)
+        response_headers = consolidate_headers(
+            response_headers, target_garden.connection_params.get("stomp_headers")
         )
         stomp_garden_connections[target_garden.name].send(
             body=message,
@@ -610,45 +612,33 @@ def _forward_http(operation: Operation, target_garden: Garden):
     """
 
     conn_info = target_garden.connection_params
-    endpoint = "{}://{}:{}{}api/v1/forward".format(
-        "https" if conn_info.get("ssl") else "http",
-        conn_info.get("host"),
-        conn_info.get("port"),
-        conn_info.get("url_prefix", "/"),
+
+    easy_client = EasyClient(
+        bg_host=conn_info.get("host"),
+        bg_port=conn_info.get("port"),
+        ssl_enabled=conn_info.get("ssl"),
+        bg_url_prefix=conn_info.get("url_prefix", "/"),
+        ca_cert=conn_info.get("ca_cert"),
+        ca_verify=conn_info.get("ca_verify"),
+        client_cert=conn_info.get("client_cert"),
     )
 
-    response = None
-
     try:
-        if conn_info.get("ssl"):
-            http_config = config.get("entry.http")
-            response = requests.post(
-                endpoint,
-                data=SchemaParser.serialize_operation(operation),
-                cert=http_config.ssl.ca_cert,
-                verify=http_config.ssl.ca_path,
-            )
-
-        else:
-            response = requests.post(
-                endpoint,
-                data=SchemaParser.serialize_operation(operation),
-                headers={"Content-type": "application/json", "Accept": "text/plain"},
-            )
+        response = easy_client.forward(operation)
 
         if response.status_code != 200:
             _publish_failed_forward(
                 operation=operation,
                 event_name=Events.GARDEN_UNREACHABLE.name,
                 error_message=f"Attempted to forward operation to garden "
-                f"'{operation.target_garden_name}' via REST but the connection returned an "
-                f"error code of {response.status_code}. Please talk to your system "
-                f"administrator.",
+                f"'{operation.target_garden_name}' via REST but the connection "
+                f"returned an error code of {response.status_code}. Please talk to "
+                f"your system administrator.",
             )
         elif target_garden.status != "RUNNING":
             beer_garden.garden.update_garden_status(target_garden.name, "RUNNING")
 
-        return response
+        return response.json()
 
     except Exception as error:
         logger.error(error)
